@@ -48,23 +48,31 @@
 
 PackUnix::PackUnix(InputFile *f) :
     super(f), exetype(0), blocksize(0), overlay_offset(0), lsize(0),
-    methods_used(0)
+    methods_used(0), szb_info(sizeof(b_info))
 {
     COMPILE_TIME_ASSERT(sizeof(Elf32_Ehdr) == 52)
     COMPILE_TIME_ASSERT(sizeof(Elf32_Phdr) == 32)
     COMPILE_TIME_ASSERT(sizeof(b_info) == 12)
     COMPILE_TIME_ASSERT(sizeof(l_info) == 12)
     COMPILE_TIME_ASSERT(sizeof(p_info) == 12)
+
+    // Disable --android-shlib, file-by-file; undecided how to fix.
+    saved_opt_android_shlib = opt->o_unix.android_shlib;
+    opt->o_unix.android_shlib = 0;
 }
 
+PackUnix::~PackUnix()
+{
+    opt->o_unix.android_shlib = saved_opt_android_shlib;
+}
 
 // common part of canPack(), enhanced by subclasses
-bool PackUnix::canPack()
+tribool PackUnix::canPack()
 {
     if (exetype == 0)
         return false;
 
-#if defined(__unix__) && !defined(__MSYS2__)
+#if defined(__unix__)
     // must be executable by owner
     if ((fi->st.st_mode & S_IXUSR) == 0)
         throwCantPack("file not executable; try 'chmod +x'");
@@ -293,11 +301,14 @@ void PackUnix::pack(OutputFile *fo)
     fi->seek(0, SEEK_SET);
     pack1(fo, ft);  // generate Elf header, etc.
 
-    p_info hbuf;
-    set_te32(&hbuf.p_progid, progid);
-    set_te32(&hbuf.p_filesize, file_size);
-    set_te32(&hbuf.p_blocksize, blocksize);
-    fo->write(&hbuf, sizeof(hbuf));
+    // Shlib probably did not generate Elf header yet.
+    if (fo->st_size()) { // Only append if pack1 actually wrote something.
+        p_info hbuf;
+        set_te32(&hbuf.p_progid, progid);
+        set_te32(&hbuf.p_filesize, file_size);
+        set_te32(&hbuf.p_blocksize, blocksize);
+        fo->write(&hbuf, sizeof(hbuf));
+    }
 
     // append the compressed body
     if (pack2(fo, ft)) {
@@ -385,7 +396,7 @@ void PackUnix::packExtent(
             ph.c_len = ph.u_len;
             memcpy(obuf, ibuf, ph.c_len);
             // must update checksum of compressed data
-            ph.c_adler = upx_adler32(ibuf, ph.u_len, ph.c_adler);
+            ph.c_adler = upx_adler32(ibuf, ph.u_len, init_c_adler);
         }
 
         // write block sizes
@@ -395,7 +406,7 @@ void PackUnix::packExtent(
             MemBuffer hdr_obuf;
             hdr_obuf.allocForCompression(hdr_u_len);
             int r = upx_compress(hdr_ibuf, hdr_u_len, hdr_obuf, &hdr_c_len, nullptr,
-                forced_method(ph.method), 10, nullptr, nullptr);
+                ph_forced_method(ph.method), 10, nullptr, nullptr);
             if (r != UPX_E_OK)
                 throwInternalError("header compression failed");
             if (hdr_c_len >= hdr_u_len)
@@ -408,7 +419,7 @@ void PackUnix::packExtent(
             memset(&tmp, 0, sizeof(tmp));
             set_te32(&tmp.sz_unc, hdr_u_len);
             set_te32(&tmp.sz_cpr, hdr_c_len);
-            tmp.b_method = (unsigned char) forced_method(ph.method);
+            tmp.b_method = (unsigned char) ph_forced_method(ph.method);
             tmp.b_extra = b_extra;
             fo->write(&tmp, sizeof(tmp));
             total_out += sizeof(tmp);
@@ -458,7 +469,7 @@ void PackUnix::packExtent(
 // Return actual length when peeking; else 0.
 unsigned PackUnix::unpackExtent(unsigned wanted, OutputFile *fo,
     unsigned &c_adler, unsigned &u_adler,
-    bool first_PF_X, unsigned szb_info,
+    bool first_PF_X,
     int is_rewrite // 0(false): write; 1(true): rewrite; -1: no write
 )
 {
@@ -544,7 +555,7 @@ unsigned PackUnix::unpackExtent(unsigned wanted, OutputFile *fo,
 **************************************************************************/
 
 // The prize is the value of overlay_offset: the offset of compressed data
-int PackUnix::canUnpack()
+tribool PackUnix::canUnpack()
 {
     int const small = 32 + sizeof(overlay_offset);
     // Allow zero-filled last page, for Mac OS X code signing.
@@ -589,13 +600,12 @@ int PackUnix::find_overlay_offset(MemBuffer const &buf)
 void PackUnix::unpack(OutputFile *fo)
 {
     b_info bhdr;
-    unsigned const szb_info = (ph.version <= 11)
-        ? sizeof(bhdr.sz_unc) + sizeof(bhdr.sz_cpr)  // old style
-        : sizeof(bhdr);
-
     unsigned c_adler = upx_adler32(nullptr, 0);
     unsigned u_adler = upx_adler32(nullptr, 0);
 
+    if (ph.version <= 11) {
+        szb_info = sizeof(bhdr.sz_unc) + sizeof(bhdr.sz_cpr);  // old style
+    }
     // defaults for ph.version == 8
     unsigned orig_file_size = 0;
     blocksize = 512 * 1024;
