@@ -127,9 +127,6 @@ static uint32_t ascii5(char *p, uint32_t v, unsigned n)
 }
 
 
-extern char *mmap(void *addr, size_t len,
-    int prot, int flags, int fd, off_t offset);
-
 #if defined(__i386__)
 #  define SET2(p, c0, c1) \
         * (unsigned short *) (p) = ((c1)<<8 | (c0))
